==> alg-common-1.22.1-20191009.085457-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/ActivityRankInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 *功能描述 广告位下优选结果
 * @author lijingzhe
 * @date 2019/9/3
 * @param
 * @return
 */

public class ActivityRankInfo {
    /**
     * 活动id
     */
    long activityId;
    /**
     * 广告位id
     */
    long slotId;
    /**
     * 媒体id
     */
    long appId;
    /**
     * 活动类型
     */
    long activityType;
    /**
     * beta win参数
     */
    double alpha = 1.5;
    /**
     * beta lose参数
     */
    double beta = 2;
    /**
     * beta 累计收益
     */
    double reward = 0;
    /**
     * beta 计数
     */
    double count = 0;
    /**
     * 转化分
     */
    double changeScore = 0;

    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    int subType = 0;
    /**
     * 是否是优质活动
     */
    boolean isExcellent = false;
    /**
     * 归一化每pv券点击
     */
    double nPvClick;
    /**
     * 归一化每pv消耗
     */
    double nPvCost;
    /**
     * 归一化表单类cvr
     */
    double nCvrForm;
    /**
     * 归一化非表单类cvr
     */
    double nCvrNotForm;
    /**
     * 归一化cvr
     */
    double nCvr;
    /**
     * 归一化得分
     */
    double score;
    /**
     * v4.0 1-扶持，2-兜底(top2~5)，3-兜底(top5~20)，4-公平竞争
     */
    int strategyType;

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public boolean isExcellent() {
        return isExcellent;
    }

    public void setExcellent(boolean excellent) {
        isExcellent = excellent;
    }

    public double getnPvClick() {
        return nPvClick;
    }

    public void setnPvClick(double nPvClick) {
        this.nPvClick = nPvClick;
    }

    public double getnPvCost() {
        return nPvCost;
    }

    public void setnPvCost(double nPvCost) {
        this.nPvCost = nPvCost;
    }

    public double getnCvrForm() {
        return nCvrForm;
    }

    public void setnCvrForm(double nCvrForm) {
        this.nCvrForm = nCvrForm;
    }

    public double getnCvrNotForm() {
        return nCvrNotForm;
    }

    public void setnCvrNotForm(double nCvrNotForm) {
        this.nCvrNotForm = nCvrNotForm;
    }

    public double getnCvr() {
        return nCvr;
    }

    public void setnCvr(double nCvr) {
        this.nCvr = nCvr;
    }

    public double getScore() {
        return score;
    }

    public void setScore(double score) {
        this.score = score;
    }

    public int getStrategyType() {
        return strategyType;
    }

    public void setStrategyType(int strategyType) {
        this.strategyType = strategyType;
    }

    @Override
    public String toString() {
        return "ActivityRankInfo{" +
                "activityId=" + activityId +
                ", slotId=" + slotId +
                ", appId=" + appId +
                ", activityType=" + activityType +
                ", alpha=" + alpha +
                ", beta=" + beta +
                ", reward=" + reward +
                ", count=" + count +
                ", changeScore=" + changeScore +
                ", subType=" + subType +
                ", isExcellent=" + isExcellent +
                ", nPvClick=" + nPvClick +
                ", nPvCost=" + nPvCost +
                ", nCvrForm=" + nCvrForm +
                ", nCvrNotForm=" + nCvrNotForm +
                ", nCvr=" + nCvr +
                ", score=" + score +
                ", strategyType=" + strategyType +
                '}';
    }
}

==> alg-common-1.25.2-20191210.034946-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/ActivityRankInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 *功能描述 广告位下优选结果
 * @author lijingzhe
 * @date 2019/9/3
 * @param
 * @return
 */

public class ActivityRankInfo {
    /**
     * 活动id
     */
    long activityId;
    /**
     * 广告位id
     */
    long slotId;
    /**
     * 媒体id
     */
    long appId;
    /**
     * 活动类型
     */
    long activityType;
    /**
     * beta win参数
     */
    double alpha = 1.5;
    /**
     * beta lose参数
     */
    double beta = 2;
    /**
     * beta 累计收益
     */
    double reward = 0;
    /**
     * beta 计数
     */
    double count = 0;
    /**
     * 转化分
     */
    double changeScore = 0;

    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    int subType = 0;
    /**
     * 是否是优质活动
     */
    boolean isExcellent = false;
    /**
     * 归一化每pv券点击
     */
    double nPvClick;
    /**
     * 归一化每pv消耗
     */
    double nPvCost;
    /**
     * 归一化表单类cvr
     */
    double nCvrForm;
    /**
     * 归一化非表单类cvr
     */
    double nCvrNotForm;
    /**
     * 归一化cvr
     */
    double nCvr;
    /**
     * 归一化得分
     */
    double score;
    /**
     * v4.0 1-扶持，2-兜底(top2~5)，3-兜底(top5~20)，4-公平竞争
     */
    int strategyType;
    /**
     * 广告位cvr
     */
    double cvrBias;
    /**
     * 广告位每uv消耗
     */
    double uvCost;
    /**
     * 广告位每uv券点击
     */
    double uvClick;
    /**
     * 广告位真实cvr
     */
    double cvr;

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public boolean isExcellent() {
        return isExcellent;
    }

    public void setExcellent(boolean excellent) {
        isExcellent = excellent;
    }

    public double getnPvClick() {
        return nPvClick;
    }

    public void setnPvClick(double nPvClick) {
        this.nPvClick = nPvClick;
    }

    public double getnPvCost() {
        return nPvCost;
    }

    public void setnPvCost(double nPvCost) {
        this.nPvCost = nPvCost;
    }

    public double getnCvrForm() {
        return nCvrForm;
    }

    public void setnCvrForm(double nCvrForm) {
        this.nCvrForm = nCvrForm;
    }

    public double getnCvrNotForm() {
        return nCvrNotForm;
    }

    public void setnCvrNotForm(double nCvrNotForm) {
        this.nCvrNotForm = nCvrNotForm;
    }

    public double getnCvr() {
        return nCvr;
    }

    public void setnCvr(double nCvr) {
        this.nCvr = nCvr;
    }

    public double getScore() {
        return score;
    }

    public void setScore(double score) {
        this.score = score;
    }

    public int getStrategyType() {
        return strategyType;
    }

    public void setStrategyType(int strategyType) {
        this.strategyType = strategyType;
    }

    public double getCvrBias() {
        return cvrBias;
    }

    public void setCvrBias(double cvrBias) {
        this.cvrBias = cvrBias;
    }

    public double getUvCost() {
        return uvCost;
    }

    public void setUvCost(double uvCost) {
        this.uvCost = uvCost;
    }

    public double getUvClick() {
        return uvClick;
    }

    public void setUvClick(double uvClick) {
        this.uvClick = uvClick;
    }

    public double getCvr() {
        return cvr;
    }

    public void setCvr(double cvr) {
        this.cvr = cvr;
    }

    @Override
    public String toString() {
        return "ActivityRankInfo{" +
                "activityId=" + activityId +
                ", slotId=" + slotId +
                ", appId=" + appId +
                ", activityType=" + activityType +
                ", alpha=" + alpha +
                ", beta=" + beta +
                ", reward=" + reward +
                ", count=" + count +
                ", changeScore=" + changeScore +
                ", subType=" + subType +
                ", isExcellent=" + isExcellent +
                ", nPvClick=" + nPvClick +
                ", nPvCost=" + nPvCost +
                ", nCvrForm=" + nCvrForm +
                ", nCvrNotForm=" + nCvrNotForm +
                ", nCvr=" + nCvr +
                ", score=" + score +
                ", strategyType=" + strategyType +
                ", cvrBias=" + cvrBias +
                ", uvCost=" + uvCost +
                ", uvClick=" + uvClick +
                ", cvr=" + cvr +
                '}';
    }
}
